/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import { StackTraceConfig } from 'jest-message-util';
import type { ModuleMocker } from 'jest-mock';
declare type Callback = (...args: Array<unknown>) => void;
declare type TimerConfig<Ref> = {
    idToRef: (id: number) => Ref;
    refToId: (ref: Ref) => number | void;
};
export default class FakeTimers<TimerRef = unknown> {
    private _cancelledTicks;
    private readonly _config;
    private _disposed;
    private _fakeTimerAPIs;
    private _fakingTime;
    private _global;
    private _immediates;
    private readonly _maxLoops;
    private readonly _moduleMocker;
    private _now;
    private _ticks;
    private readonly _timerAPIs;
    private _timers;
    private _uuidCounter;
    private readonly _timerConfig;
    constructor({ global, moduleMocker, timerConfig, config, maxLoops, }: {
        global: typeof globalThis;
        moduleMocker: ModuleMocker;
        timerConfig: TimerConfig<TimerRef>;
        config: StackTraceConfig;
        maxLoops?: number;
    });
    clearAllTimers(): void;
    dispose(): void;
    reset(): void;
    now(): number;
    runAllTicks(): void;
    runAllImmediates(): void;
    private _runImmediate;
    runAllTimers(): void;
    runOnlyPendingTimers(): void;
    advanceTimersToNextTimer(steps?: number): void;
    advanceTimersByTime(msToRun: number): void;
    runWithRealTimers(cb: Callback): void;
    useRealTimers(): void;
    useFakeTimers(): void;
    getTimerCount(): number;
    private _checkFakeTimers;
    private _createMocks;
    private _fakeClearTimer;
    private _fakeClearImmediate;
    private _fakeNextTick;
    private _fakeRequestAnimationFrame;
    private _fakeSetImmediate;
    private _fakeSetInterval;
    private _fakeSetTimeout;
    private _getNextTimerHandleAndExpiry;
    private _runTimerHandle;
}
export {};
