/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import type { Config } from '@jest/types';
import * as constants from './constants';
export { isJSONString } from './utils';
export { default as normalize } from './normalize';
export { default as deprecationEntries } from './Deprecated';
export { replaceRootDirInPath } from './utils';
export { default as defaults } from './Defaults';
export { default as descriptions } from './Descriptions';
export { constants };
declare type ReadConfig = {
    configPath: string | null | undefined;
    globalConfig: Config.GlobalConfig;
    hasDeprecationWarnings: boolean;
    projectConfig: Config.ProjectConfig;
};
export declare function readConfig(argv: Config.Argv, packageRootOrConfig: string | Config.InitialOptions, skipArgvConfigOption?: boolean, parentConfigDirname?: string | null, projectIndex?: number, skipMultipleConfigError?: boolean): Promise<ReadConfig>;
export interface ReadJestConfigOptions {
    /**
     * The package root or deserialized config (default is cwd)
     */
    packageRootOrConfig?: string | Config.InitialOptions;
    /**
     * When the `packageRootOrConfig` contains config, this parameter should
     * contain the dirname of the parent config
     */
    parentConfigDirname?: null | string;
    /**
     * Indicates whether or not to read the specified config file from disk.
     * When true, jest will read try to read config from the current working directory.
     * (default is false)
     */
    readFromCwd?: boolean;
    /**
     * Indicates whether or not to ignore the error of jest finding multiple config files.
     * (default is false)
     */
    skipMultipleConfigError?: boolean;
}
/**
 * Reads the jest config, without validating them or filling it out with defaults.
 * @param config The path to the file or serialized config.
 * @param param1 Additional options
 * @returns The raw initial config (not validated)
 */
export declare function readInitialOptions(config?: string, { packageRootOrConfig, parentConfigDirname, readFromCwd, skipMultipleConfigError, }?: ReadJestConfigOptions): Promise<{
    config: Config.InitialOptions;
    configPath: string | null;
}>;
export declare function readConfigs(argv: Config.Argv, projectPaths: Array<string>): Promise<{
    globalConfig: Config.GlobalConfig;
    configs: Array<Config.ProjectConfig>;
    hasDeprecationWarnings: boolean;
}>;
