/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 */
import type { Circus } from '@jest/types';
import { QueueableFn } from '../queueRunner';
import type { AssertionErrorWithStack, Jasmine, Reporter, SpecDefinitionsFn, Spy } from '../types';
import type { default as Spec } from './Spec';
import type Suite from './Suite';
export default function jasmineEnv(j$: Jasmine): {
    new (): {
        specFilter: (spec: Spec) => boolean;
        catchExceptions: (value: unknown) => boolean;
        throwOnExpectationFailure: (value: unknown) => void;
        catchingExceptions: () => boolean;
        topSuite: () => Suite;
        fail: (error: Error | AssertionErrorWithStack) => void;
        pending: (message: string) => void;
        afterAll: (afterAllFunction: QueueableFn['fn'], timeout?: number) => void;
        fit: (description: Circus.TestNameLike, fn: QueueableFn['fn'], timeout?: number) => Spec;
        throwingExpectationFailures: () => boolean;
        randomizeTests: (value: unknown) => void;
        randomTests: () => boolean;
        seed: (value: unknown) => unknown;
        execute: (runnablesToRun?: Array<string>, suiteTree?: Suite) => Promise<void>;
        fdescribe: (description: Circus.TestNameLike, specDefinitions: SpecDefinitionsFn) => Suite;
        spyOn: (obj: Record<string, Spy>, methodName: string, accessType?: keyof PropertyDescriptor) => Spy;
        beforeEach: (beforeEachFunction: QueueableFn['fn'], timeout?: number) => void;
        afterEach: (afterEachFunction: QueueableFn['fn'], timeout?: number) => void;
        clearReporters: () => void;
        addReporter: (reporterToAdd: Reporter) => void;
        it: (description: Circus.TestNameLike, fn: QueueableFn['fn'], timeout?: number) => Spec;
        xdescribe: (description: Circus.TestNameLike, specDefinitions: SpecDefinitionsFn) => Suite;
        xit: (description: Circus.TestNameLike, fn: QueueableFn['fn'], timeout?: number) => Spec;
        beforeAll: (beforeAllFunction: QueueableFn['fn'], timeout?: number) => void;
        todo: () => Spec;
        provideFallbackReporter: (reporterToAdd: Reporter) => void;
        allowRespy: (allow: boolean) => void;
        describe: (description: Circus.TestNameLike, specDefinitions: SpecDefinitionsFn) => Suite;
    };
};
